@@ -5,7 +5,7 @@
 #include <QFontDatabase>
 
 Config::Config(QObject *parent)
-    : MarknoteSettings(parent)
+    : QObject(parent)
 {
 }
 
@@ -13,8 +13,3 @@ QStringList Config::fontFamilies() const
 {
     return QFontDatabase::families();
 }
-
-void Config::reset()
-{
-    setEditorFont(defaultEditorFontValue());
-}
