@@ -9,7 +9,9 @@
 #include <KLocalizedString>
 #include <KStandardShortcut>
 
+#include <QAbstractTextDocumentLayout>
 #include <QClipboard>
+#include <QDesktopServices>
 #include <QFile>
 #include <QFileInfo>
 #include <QGuiApplication>
@@ -58,6 +60,23 @@ bool DocumentHandler::eventFilter(QObject *object, QEvent *event)
     if (object == m_textArea && event->type() == QEvent::KeyPress) {
         return !processKeyEvent(static_cast<QKeyEvent *>(event));
     }
+
+    // activate only links covered by press and release, on release
+    // matches the behavior of TextArea::linkActivated
+    // we can't use that directly though as it prevents placing the cursor inside a link
+    if (auto me = static_cast<QMouseEvent *>(event);
+        object == m_textArea && event->type() == QEvent::MouseButtonPress && me->modifiers() == Qt::ControlModifier) {
+        m_activeLink = m_document->textDocument()->documentLayout()->anchorAt(me->position());
+    }
+    if (auto me = static_cast<QMouseEvent *>(event);
+        object == m_textArea && event->type() == QEvent::MouseButtonRelease && me->modifiers() == Qt::ControlModifier) {
+        const auto link = m_document->textDocument()->documentLayout()->anchorAt(me->position());
+        if (!link.isEmpty() && m_activeLink == link) {
+            QDesktopServices::openUrl(QUrl(link));
+            return true;
+        }
+        m_activeLink.clear();
+    }
     return false;
 }
 
@@ -399,7 +418,11 @@ void DocumentHandler::load(const QUrl &fileUrl)
                         cursor.setPosition(pos + 1, QTextCursor::KeepAnchor);
                         cursor.removeSelectedText();
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+                        cursor.insertHtml(u"<img style=\"max-width: 100%\" src=\""_s + imageFormat.name() + u"\"\\>"_s);
+#else
                         cursor.insertHtml(u"<img width=\"500\" src=\""_s + imageFormat.name() + u"\"\\>"_s);
+#endif
                         // The textfragment iterator is now invalid, restart from the beginning
                         // Take care not to replace the same fragment again, or we would be in
                         // an infinite loop.
@@ -478,7 +501,6 @@ QTextDocument *DocumentHandler::textDocument() const
 {
     if (!m_document)
         return nullptr;
-
     return m_document->textDocument();
 }
 
@@ -721,7 +743,11 @@ void DocumentHandler::insertImage(const QUrl &url)
         m_nestedListHelper.handleOnIndentLess(textCursor());
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    textCursor().insertHtml(u"<img style=\"max-width: 100%\" src=\""_s + url.path() + u"\"\\>"_s);
+#else
     textCursor().insertHtml(u"<img width=\"500\" src=\""_s + url.path() + u"\"\\>"_s);
+#endif
 }
 
 void DocumentHandler::insertTable(int rows, int columns)
@@ -1044,29 +1070,36 @@ bool DocumentHandler::processKeyEvent(QKeyEvent *e)
         && textCursor().block().layout()->lineForTextPosition(textCursor().position()).lineNumber() == 0) {
         textCursor().clearSelection();
         Q_EMIT focusUp();
-    } else {
-        QTextTable *table = textCursor().currentTable();
-        const bool isTable = (table != nullptr);
-        if (isTable && (e->key() == Qt::Key_Backtab || e->key() == Qt::Key_Tab)) {
-            // navigate to previous or next table cell
-            auto cursor = textCursor();
-            auto ok = cursor.movePosition(e->key() == Qt::Key_Tab ? QTextCursor::NextCell : QTextCursor::PreviousCell);
-            if (!ok) {
-                ok = cursor.movePosition(e->key() == Qt::Key_Tab ? QTextCursor::NextBlock : QTextCursor::PreviousBlock);
-                moveCursor(cursor.position());
-            } else {
-                cursor.movePosition(QTextCursor::StartOfLine);
-                const int start = cursor.position();
-                cursor.movePosition(QTextCursor::EndOfLine);
-                const int end = cursor.position();
-                selectCursor(start, end);
-            }
-            return false;
-        } else {
-            return evaluateReturnKeySupport(e);
-        }
+        return true;
     }
-    return true;
+
+    if (textCursor().currentTable() && (e->key() == Qt::Key_Backtab || e->key() == Qt::Key_Tab)) {
+        // navigate to previous or next table cell
+        auto cursor = textCursor();
+        auto ok = cursor.movePosition(e->key() == Qt::Key_Tab ? QTextCursor::NextCell : QTextCursor::PreviousCell);
+        if (!ok) {
+            ok = cursor.movePosition(e->key() == Qt::Key_Tab ? QTextCursor::NextBlock : QTextCursor::PreviousBlock);
+            moveCursor(cursor.position());
+        } else {
+            cursor.movePosition(QTextCursor::StartOfLine);
+            const int start = cursor.position();
+            cursor.movePosition(QTextCursor::EndOfLine);
+            const int end = cursor.position();
+            selectCursor(start, end);
+        }
+        return false;
+    }
+
+    if (e->key() == Qt::Key_Tab && canIndentList()) {
+        indentListMore();
+        return false;
+    }
+    if (e->key() == Qt::Key_Backtab && canDedentList()) {
+        indentListLess();
+        return false;
+    }
+
+    return evaluateReturnKeySupport(e);
 }
 
 bool DocumentHandler::handleShortcut(QKeyEvent *event)
