@@ -5,10 +5,8 @@
 #include <KConfigGroup>
 #include <KDesktopFile>
 #include <KLocalizedString>
-#include <QDateTime>
 #include <QDebug>
 #include <QFile>
-#include <QFileSystemWatcher>
 #include <QPdfWriter>
 #include <QStandardPaths>
 #include <QTextBlock>
@@ -65,14 +63,14 @@ QVariant NotesModel::data(const QModelIndex &index, int role) const
         return entry.fileName();
     case Role::Date:
         return entry.lastModified(QTimeZone::LocalTime);
+    case Role::Month:
+        return entry.lastModified(QTimeZone::LocalTime).toString(u"MMMM yyyy"_s);
     case Role::Name:
         return entry.fileName().replace(QStringLiteral(".md"), QString());
     case Role::Color:
         return m_color;
     }
 
-    Q_UNREACHABLE();
-
     return {};
 }
 
@@ -84,12 +82,13 @@ QHash<int, QByteArray> NotesModel::roleNames() const
         {Role::FileUrl, "fileUrl"},
         {Role::Name, "name"},
         {Role::Color, "color"},
+        {Role::Month, "month"},
     };
 }
 
 QString NotesModel::addNote(const QString &name)
 {
-    const QString path = m_path + QDir::separator() + name + QStringLiteral(".md");
+    const QString path = m_path + u'/' + name + QStringLiteral(".md");
     QFile file(path);
     if (file.open(QFile::WriteOnly)) {
         file.write("# " + name.toUtf8());
@@ -108,7 +107,7 @@ void NotesModel::deleteNote(const QUrl &path)
 
 void NotesModel::renameNote(const QUrl &path, const QString &name)
 {
-    QString newPath = m_path + QDir::separator() + name + QStringLiteral(".md");
+    QString newPath = m_path + u'/' + name + QStringLiteral(".md");
     if (QFile::exists(newPath)) {
         Q_EMIT errorOccured(i18nc("@info:status", "Unable to rename note. A note already exists with the same name."));
         return;
@@ -128,7 +127,7 @@ void NotesModel::setPath(const QString &newPath)
         return;
 
     if (!m_path.isEmpty()) {
-        m_watcher.removePath(m_path + QDir::separator() + QStringLiteral(".directory"));
+        m_watcher.removePath(m_path + u'/' + QStringLiteral(".directory"));
     }
     m_path = newPath;
     updateEntries();
@@ -137,13 +136,13 @@ void NotesModel::setPath(const QString &newPath)
     updateColor();
 
     if (!m_path.isEmpty()) {
-        m_watcher.addPath(m_path + QDir::separator() + QStringLiteral(".directory"));
+        m_watcher.addPath(m_path + u'/' + QStringLiteral(".directory"));
     }
 }
 
 void NotesModel::updateColor()
 {
-    const QString dotDirectory = m_path + QDir::separator() + QStringLiteral(".directory");
+    const QString dotDirectory = m_path + u'/' + QStringLiteral(".directory");
     if (QFile::exists(dotDirectory)) {
         m_color = KDesktopFile(dotDirectory).desktopGroup().readEntry("X-MarkNote-Color");
     } else {
@@ -324,3 +323,5 @@ void NotesModel::exportToOdt(const QUrl &path, const QUrl &destination)
     QTextDocumentWriter writer(destination.toLocalFile(), "odf");
     writer.write(&doc);
 }
+
+#include "moc_notesmodel.cpp"
